import { Box, Grid, Typography, Skeleton } from "@mui/material";
import { styled } from "@mui/material/styles";
import React, { ReactNode, useState } from "react";
import { useChainId } from "wagmi";

import { DecimalBigNumber } from "../../helpers/DecimalBigNumber";
import { useAllowance, approveTokens } from "../../hooks/tokens";
import { PrimaryButton } from "../Button";

const PREFIX = "TokenAllowanceGuard";

const classes = {
    inputRow: `${PREFIX}-inputRow`,
    gridItem: `${PREFIX}-gridItem`,
    input: `${PREFIX}-input`,
    button: `${PREFIX}-button`,
};

const StyledAllowanceGuard = styled("div")(({ theme }) => ({
    [`& .${classes.inputRow}`]: {
        justifyContent: "space-around",
        alignItems: "center",
        height: "auto",
        marginTop: "4px",
    },

    [`& .${classes.gridItem}`]: {
        width: "100%",
        paddingRight: "5px",
        alignItems: "center",
        justifyContent: "center",
    },

    [`& .${classes.input}`]: {
        [theme.breakpoints.down("md")]: {
            marginBottom: "10px",
        },
        [theme.breakpoints.up("sm")]: {
            marginBottom: "0",
        },
    },

    [`& .${classes.button}`]: {
        alignSelf: "center",
        width: "100%",
        minWidth: "163px",
        maxWidth: "542px",
        height: "43px",
    },
}));

export const TokenAllowanceGuard = ({
    message,
    isVertical = false,
    approvalText = "Approve",
    approvalPendingText = "Approving...",
    width = "150px",
    height = "auto",
    spendAmount,
    tokenName,
    owner,
    spender,
    decimals,
    connect,
    children,
}) => {
    const chainId = useChainId();
    const [isPending, setIsPending] = useState(false);

    const {
        allowance: allowance,
        refetch: allowanceRefetch
    } = useAllowance(chainId, tokenName, owner, spender, decimals);

    const approve = async () => {
        setIsPending(true);
        const bigValue = 100000000000000000000000000000000000000000000000000n;
        await approveTokens(chainId, tokenName, owner, spender, bigValue);
        await allowanceRefetch();
        setIsPending(false);
    }

    if (!allowance) {
        return (
            <Box display="flex" alignItems="center" justifyContent="center" height={isVertical ? "84px" : "40px"}>
                <Skeleton height={height} width={width} />
            </Box>
        );
    }

    if (allowance && spendAmount && allowance.lt(spendAmount))
        return (
            <Grid container alignItems="center">
                <Grid item xs={12} sm={isVertical ? 12 : 8}>
                    <Box display="flex" textAlign="center" alignItems="center" justifyContent="center">
                        <Typography mr="10px" variant="body2" color="textSecondary">
                            <em>{owner === ""
                                ? message ? message : "There is no connected wallet to check if allowance is sufficient."
                                : "Your current allowance is less than your requested spend amount."
                            }</em>
                        </Typography>
                    </Box>
                </Grid>

                <Grid item xs={12} sm={isVertical ? 12 : 4}>
                    <Box display="flex" alignItems="center" justifyContent="center" mt={[2, isVertical && message ? 2 : 0]}>
                        <PrimaryButton
                            fullWidth
                            disabled={isPending}
                            loading={isPending}
                            onClick={() => owner === "" ? connect() : approve()}
                        >
                            {owner === "" ?
                                "Connect"
                                :
                                isPending ? `${approvalPendingText}` : `${approvalText}`
                            }
                        </PrimaryButton>
                    </Box>
                </Grid>
            </Grid>
        );

    return <StyledAllowanceGuard>{children}</StyledAllowanceGuard>;
};
