import {
    Box,
    FormControlLabel,
    FormControl,
    InputAdornment,
    InputLabel,
    OutlinedInput,
    Checkbox,
    Typography
} from "@mui/material";
import { CheckBoxOutlineBlank, CheckBoxOutlined } from "@mui/icons-material";

import Modal from "../../../components/Modal/Modal";

const StakeSettingsModal = props => {
    return (
        <Modal
            id="hades"
            maxWidth="408px"
            minHeight="350px"
            headerText="Settings"
            open={props.open}
            onClose={props.onClose}
        >
            <Box>
                <Box mt="8px">
                    <FormControlLabel
                        control={
                            <Checkbox
                                inputProps={{ "data-testid": "instant-claim" }}
                                id="instant-claim"
                                checked={props.isClaim}
                                onChange={event => props.onIsClaimChanged(event.target.checked)}
                                icon={<CheckBoxOutlineBlank viewBox="0 0 24 24" />}
                                checkedIcon={<CheckBoxOutlined viewBox="0 0 24 24" />}
                            />
                        }
                        label={<Typography variant="body2">Always try to claim during stake, works only if warmup period is zero</Typography>}
                    />
                </Box>
            </Box>

            <Box mt="32px">
                <FormControlLabel
                    control={
                        <Checkbox
                            inputProps={{ "data-testid": "instant-claim" }}
                            id="instant-claim"
                            checked={props.isTrigger}
                            onChange={event => props.onTriggerRebaseChange(event.target.checked)}
                            icon={<CheckBoxOutlineBlank viewBox="0 0 24 24" />}
                            checkedIcon={<CheckBoxOutlined viewBox="0 0 24 24" />}
                        />
                    }
                    label={<Typography variant="body2">Try to trigger rebase on each unstake, can influence on received amount</Typography>}
                />
            </Box>

            <Box mt="32px">
                <InputLabel htmlFor="decimals">Decimals</InputLabel>
                <Box mt="8px">
                    <FormControl variant="outlined" color="primary" fullWidth>
                        <OutlinedInput
                            inputProps={{ "data-testid": "decimals" }}
                            type="number"
                            id="decimals"
                            value={props.formatDecimals}
                            onChange={props.onFormatDecimalsChange}
                        />
                    </FormControl>
                </Box>
                <Box mt="8px">
                    <Typography variant="body2" color="textSecondary">
                        Number of decimals to be shown in token balances
                    </Typography>
                </Box>
            </Box>
        </Modal>
    );
};

export default StakeSettingsModal;
